summaryrefslogtreecommitdiff
path: root/gdk/gdkpixbuf-render.c
diff options
context:
space:
mode:
authorMatthias Clasen <maclas@gmx.de>2003-01-31 00:37:38 +0000
committerMatthias Clasen <matthiasc@src.gnome.org>2003-01-31 00:37:38 +0000
commit46d15e32bda614d503216aa877251b523231ee9a (patch)
treee994def37c8ecf56595904f4e953731cd4d4c826 /gdk/gdkpixbuf-render.c
parent2435e831cfe93e3ac9609338841c2af03889c6c4 (diff)
downloadgtk+-46d15e32bda614d503216aa877251b523231ee9a.tar.gz
Deprecate. (#60582)
2003-01-31 Matthias Clasen <maclas@gmx.de> * gdk/gdkpixbuf.h: * gdk/gdkpixbuf-render.c (gdk_pixbuf_render_to_drawable): (gdk_pixbuf_render_to_drawable_alpha): Deprecate. (#60582) * gtk/gtkcolorsel.h: * gtk/gtkcolorsel.c (gtk_color_selection_set_change_palette_hook): Deprecate. (#98167)
Diffstat (limited to 'gdk/gdkpixbuf-render.c')
-rw-r--r--gdk/gdkpixbuf-render.c20
1 files changed, 9 insertions, 11 deletions
diff --git a/gdk/gdkpixbuf-render.c b/gdk/gdkpixbuf-render.c
index ef920b8b66..8095188d95 100644
--- a/gdk/gdkpixbuf-render.c
+++ b/gdk/gdkpixbuf-render.c
@@ -164,7 +164,7 @@ gdk_pixbuf_render_threshold_alpha (GdkPixbuf *pixbuf,
* for consistent visual results. If you do not have any of these cases, the
* dither offsets can be both zero.
*
- * This function is obsolete. Use gdk_draw_pixbuf() instead.
+ * Deprecated: This function is obsolete. Use gdk_draw_pixbuf() instead.
**/
void
gdk_pixbuf_render_to_drawable (GdkPixbuf *pixbuf,
@@ -207,7 +207,7 @@ gdk_pixbuf_render_to_drawable (GdkPixbuf *pixbuf,
* On older X servers, rendering pixbufs with an alpha channel involves round trips
* to the X server, and may be somewhat slow.
*
- * This function is obsolete. Use gdk_draw_pixbuf() instead.
+ * Deprecated: This function is obsolete. Use gdk_draw_pixbuf() instead.
**/
void
gdk_pixbuf_render_to_drawable_alpha (GdkPixbuf *pixbuf,
@@ -238,8 +238,7 @@ gdk_pixbuf_render_to_drawable_alpha (GdkPixbuf *pixbuf,
* and @mask_return arguments, respectively, and renders a pixbuf and its
* corresponding thresholded alpha mask to them. This is merely a convenience
* function; applications that need to render pixbufs with dither offsets or to
* given drawables should use gdk_pixbuf_render_to_drawable_alpha() or
* gdk_pixbuf_render_to_drawable(), and gdk_pixbuf_render_threshold_alpha().
*
* The pixmap that is created is created for the colormap returned
* by gdk_rgb_get_colormap(). You normally will want to instead use
@@ -275,8 +274,7 @@ gdk_pixbuf_render_pixmap_and_mask (GdkPixbuf *pixbuf,
* and @mask_return arguments, respectively, and renders a pixbuf and its
* corresponding tresholded alpha mask to them. This is merely a convenience
* function; applications that need to render pixbufs with dither offsets or to
* given drawables should use gdk_pixbuf_render_to_drawable_alpha() or
* gdk_pixbuf_render_to_drawable(), and gdk_pixbuf_render_threshold_alpha().
*
* The pixmap that is created uses the #GdkColormap specified by @colormap.
* This colormap must match the colormap of the window where the pixmap
@@ -308,11 +306,11 @@ gdk_pixbuf_render_pixmap_and_mask_for_colormap (GdkPixbuf *pixbuf,
gdk_drawable_set_colormap (GDK_DRAWABLE (*pixmap_return), colormap);
gc = gdk_gc_new (*pixmap_return);
- gdk_pixbuf_render_to_drawable (pixbuf, *pixmap_return, gc,
- 0, 0, 0, 0,
- gdk_pixbuf_get_width (pixbuf), gdk_pixbuf_get_height (pixbuf),
- GDK_RGB_DITHER_NORMAL,
- 0, 0);
+ gdk_draw_pixbuf (*pixmap_return, gc, pixbuf,
+ 0, 0, 0, 0,
+ gdk_pixbuf_get_width (pixbuf), gdk_pixbuf_get_height (pixbuf),
+ GDK_RGB_DITHER_NORMAL,
+ 0, 0);
g_object_unref (gc);
}
@@ -238,8 +238,7 @@ gdk_pixbuf_render_to_drawable_alpha (GdkPixbuf *pixbuf,
* corresponding thresholded alpha mask to them. This is merely a convenience
* function; applications that need to render pixbufs with dither offsets or to
- * given drawables should use gdk_pixbuf_render_to_drawable_alpha() or
- * gdk_pixbuf_render_to_drawable(), and gdk_pixbuf_render_threshold_alpha().
+ * given drawables should use gdk_draw_pixbuf() and gdk_pixbuf_render_threshold_alpha().
*
* The pixmap that is created is created for the colormap returned
@@ -275,8 +274,7 @@ gdk_pixbuf_render_pixmap_and_mask (GdkPixbuf *pixbuf,
* corresponding tresholded alpha mask to them. This is merely a convenience
* function; applications that need to render pixbufs with dither offsets or to
- * given drawables should use gdk_pixbuf_render_to_drawable_alpha() or
- * gdk_pixbuf_render_to_drawable(), and gdk_pixbuf_render_threshold_alpha().
+ * given drawables should use gdk_draw_pixbuf(), and gdk_pixbuf_render_threshold_alpha().
*
* The pixmap that is created uses the #GdkColormap specified by @colormap.